@@ -1,11 +1,10 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import os, sys, json, time, base64
+import os, sys, json, time, base64, copy
 from io import open
 
 from . import register_parser, logger, config, __version__
 from .util.aws import locate_ami, add_tags, get_bdm, resolve_instance_id, resources, clients, ARN, AegeaException
 from .util.aws.ssm import run_command
+from .util.cloudinit import get_rootfs_skel_dirs
 from .util.crypto import ensure_ssh_key, get_ssh_key_path
 from .util.printing import GREEN
 from .launch import launch, parser as launch_parser
@@ -23,13 +22,13 @@ def build_ami(args):
     else:
         if args.base_ami == "auto":
             distribution, release = args.base_ami_distribution.split(":", 1)
-            args.ami = locate_ami(distribution=distribution, release=release, architecture=args.architecture)
+            args.ami = locate_ami(distribution=distribution, release=release, architecture=args.architecture).id
         else:
             args.ami = args.base_ami
         hostname = "{}-{}-{}".format(__name__, args.name, int(time.time())).replace(".", "-").replace("_", "-")
-        launch_args = launch_parser.parse_args(args=[hostname], namespace=args)
+        launch_args = launch_parser.parse_args(args=[hostname], namespace=copy.deepcopy(args))
         launch_args.iam_role = args.iam_role
-        launch_args.cloud_config_data.update(rootfs_skel_dirs=args.rootfs_skel_dirs)
+        launch_args.cloud_config_data.update(rootfs_skel_dirs=get_rootfs_skel_dirs(args))
         instance = resources.ec2.Instance(launch(launch_args)["instance_id"])
     sys.stderr.write("Waiting {} seconds for cloud-init ...".format(args.cloud_init_timeout_seconds))
     sys.stderr.flush()
@@ -52,14 +51,14 @@ def build_ami(args):
             else:
                 raise
     else:
-        raise Exception("cloud-init encountered errors")
+        raise AegeaException("cloud-init encountered errors; please examine and terminate {}".format(instance))
     sys.stderr.write(GREEN("OK") + "\n")
     description = "Built by {} for {}".format(__name__, ARN.get_iam_username())
     for existing_ami in resources.ec2.images.filter(Owners=["self"], Filters=[{"Name": "name", "Values": [args.name]}]):
         logger.info("Deleting existing image {}".format(existing_ami))
         existing_ami.deregister()
     image = instance.create_image(Name=args.name, Description=description, BlockDeviceMappings=get_bdm())
-    tags = dict(tag.split("=", 1) for tag in args.tags)
+    tags = dict(args.tags)
     base_ami = resources.ec2.Image(args.ami)
     tags.update(Owner=ARN.get_iam_username(), AegeaVersion=__version__,
                 Base=base_ami.id, BaseName=base_ami.name, BaseDescription=base_ami.description or "")
@@ -88,7 +87,8 @@ parser.add_argument("--base-ami")
 parser.add_argument("--base-ami-distribution",
                     help="Use AMI for this distribution (examples: Ubuntu:20.04, Amazon Linux:2")
 parser.add_argument("--dry-run", "--dryrun", action="store_true")
-parser.add_argument("--tags", nargs="+", default=[], metavar="NAME=VALUE", help="Tag the resulting AMI with these tags")
+parser.add_argument("--tags", nargs="+", metavar="NAME=VALUE", type=lambda x: x.split("=", 1),
+                    help="Tag the resulting AMI with these tags")
 parser.add_argument("--cloud-config-data", type=json.loads)
 parser.add_argument("--cloud-init-timeout-seconds", type=int,
                     help="Approximate time in seconds to wait for cloud-init to finish before aborting.")
