@@ -21,7 +21,6 @@ Examples:
 - Launch a spot r5d.xlarge instance with the home directory mounted on EFS:
     aegea launch my-instance --spot-price 1 --instance-type r5d.xlarge --efs-home
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import os, sys, time, datetime, base64, json
 from typing import Dict, List
@@ -32,7 +31,7 @@ from . import register_parser, logger, config
 from .efs import create as create_efs, parser_create as parser_create_efs, __name__ as efs_security_group_name
 from .ssh import get_user_info
 from .util import wait_for_port, validate_hostname, paginate
-from .util.cloudinit import get_user_data
+from .util.cloudinit import get_user_data, get_rootfs_skel_dirs
 from .util.aws import (ensure_vpc, ensure_subnet, ensure_security_group, ensure_log_group,
                        add_tags, resolve_security_group, get_bdm, resolve_instance_id, expect_error_codes, resolve_ami,
                        locate_ami, get_ondemand_price_usd, resources, clients, ARN, instance_type_completer,
@@ -42,7 +41,7 @@ from .util.aws.spot import SpotFleetBuilder
 from .util.aws.iam import ensure_instance_profile, compose_managed_policies
 from .util.crypto import new_ssh_key, add_ssh_host_key_to_known_hosts, ensure_ssh_key, hostkey_line
 from .util.exceptions import AegeaException
-from botocore.exceptions import ClientError
+from botocore.exceptions import ClientError, WaiterError
 
 def get_spot_bid_price(instance_type, ondemand_multiplier=1.2):
     ondemand_price = get_ondemand_price_usd(clients.ec2.meta.region_name, instance_type)
@@ -73,7 +72,21 @@ def infer_architecture(instance_type):
         return "arm64"
     return "x86_64"
 
+def ensure_efs_home(subnet):
+    for fs in clients.efs.describe_file_systems()["FileSystems"]:
+        if {"Key": "mountpoint", "Value": "/home"} in fs["Tags"]:
+            for mt in paginate(clients.efs.get_paginator("describe_mount_targets"), FileSystemId=fs["FileSystemId"]):
+                if mt["VpcId"] == subnet.vpc_id and mt["AvailabilityZoneName"] == subnet.availability_zone:
+                    logger.info("Using %s for EFS home", fs["FileSystemId"])
+                    return fs
+    create_efs_args = ["aegea_home", "--tags", "mountpoint=/home", "managedBy=aegea", "--vpc", subnet.vpc_id]
+    return create_efs(parser_create_efs.parse_args(create_efs_args))
+
 def launch(args):
+    args.storage = dict(args.storage)  # Allow storage to be specified as either a list (argparse) or mapping (YAML)
+    args.storage = {k: str(v).rstrip("GBgb") for k, v in args.storage.items()}
+    logger.debug('Using %s for storage', ', '.join('='.join(_) for _ in args.storage.items()))
+
     if args.spot_price or args.duration_hours or args.cores or args.min_mem_per_core_gb:
         args.spot = True
     if args.use_dns:
@@ -104,7 +117,7 @@ def launch(args):
             if not (args.ami or args.ami_tags or args.ami_tag_keys):
                 args.ami_tag_keys.append("AegeaVersion")
             args.ami = resolve_ami(args.ami, tags=ami_tags, tag_keys=args.ami_tag_keys, arch=arch)
-            logger.info("Using %s", args.ami)
+            logger.info("Using %s (%s)", args.ami, args.ami.name)
         except AegeaException as e:
             if args.ami is None and len(ami_tags) == 0 and "Could not resolve AMI" in str(e):
                 raise AegeaException("No AMI was given, and no " + arch + " AMIs were found in this account. "
@@ -135,23 +148,20 @@ def launch(args):
         security_groups = [ensure_security_group(__name__, vpc)]
 
     if args.efs_home:
-        for filesystem in clients.efs.describe_file_systems()["FileSystems"]:
-            if {"Key": "mountpoint", "Value": "/home"} in filesystem["Tags"]:
-                break
-        else:
-            create_efs_args = ["aegea_home", "--tags", "mountpoint=/home", "managedBy=aegea"]
-            create_efs(parser_create_efs.parse_args(create_efs_args), vpc=vpc)
+        ensure_efs_home(subnet)
         security_groups.append(resolve_security_group(efs_security_group_name, vpc))
 
     ssh_host_key = new_ssh_key()
     user_data_args = dict(host_key=ssh_host_key,
                           commands=get_startup_commands(args),
                           packages=args.packages,
-                          storage=args.storage)
+                          storage=args.storage,
+                          rootfs_skel_dirs=get_rootfs_skel_dirs(args))
     if args.provision_user:
         user_data_args["provision_users"] = [dict(name=user_info["linux_username"],
                                                   uid=user_info["linux_user_id"],
                                                   sudo="ALL=(ALL) NOPASSWD:ALL",
+                                                  groups="docker",
                                                   shell="/bin/bash")]
     elif args.bless_config:
         with open(args.bless_config) as fh:
@@ -164,18 +174,27 @@ def launch(args):
                          SSHHostPublicKeyPart1=hkl[:255], SSHHostPublicKeyPart2=hkl[255:],
                          OwnerSSHKeyName=ssh_key_name, **dict(args.tags))
     user_data_args.update(dict(args.cloud_config_data))
-    launch_spec = dict(ImageId=args.ami,
+    launch_spec = dict(ImageId=args.ami.id,
                        KeyName=ssh_key_name,
                        SubnetId=subnet.id,
                        SecurityGroupIds=[sg.id for sg in security_groups],
                        InstanceType=args.instance_type,
-                       BlockDeviceMappings=get_bdm(ami=args.ami, ebs_storage=args.storage),
+                       BlockDeviceMappings=get_bdm(ami=args.ami.id, ebs_storage=args.storage),
                        UserData=get_user_data(**user_data_args))
     tag_spec = dict(ResourceType="instance", Tags=encode_tags(instance_tags))
     logger.info("Launch spec user data is %i bytes long", len(launch_spec["UserData"]))
     if args.iam_role:
-        umbrella_policy = compose_managed_policies(args.iam_policies)
-        instance_profile = ensure_instance_profile(args.iam_role, policies=[umbrella_policy])
+        logger.debug("Using %s for iam_role", args.iam_role)
+        if args.manage_iam:
+            try:
+                umbrella_policy = compose_managed_policies(args.iam_policies)
+                instance_profile = ensure_instance_profile(args.iam_role, policies=[umbrella_policy])
+            except ClientError as e:
+                expect_error_codes(e, "AccessDenied")
+                raise AegeaException('Unable to validate IAM permissions for launch. If you have only iam:PassRole '
+                                     'access, try --no-manage-iam. If you have no IAM access, try --iam-role="".')
+        else:
+            instance_profile = resources.iam.InstanceProfile(args.iam_role)
         launch_spec["IamInstanceProfile"] = dict(Arn=instance_profile.arn)
     if args.availability_zone:
         launch_spec["Placement"] = dict(AvailabilityZone=args.availability_zone)
@@ -235,7 +254,7 @@ def launch(args):
             instances = resources.ec2.create_instances(MinCount=1, MaxCount=1, ClientToken=args.client_token,
                                                        DryRun=args.dry_run, **launch_spec)
             instance = instances[0]
-    except KeyboardInterrupt:
+    except (KeyboardInterrupt, WaiterError):
         if sir_id is not None and instance is None:
             logger.error("Canceling spot instance request %s", sir_id)
             clients.ec2.cancel_spot_instance_requests(SpotInstanceRequestIds=[sir_id])
@@ -244,22 +263,20 @@ def launch(args):
         expect_error_codes(e, "DryRunOperation")
         logger.info("Dry run succeeded")
         exit()
-    while instance.state["Name"] != "running":
-        logger.debug("%s %s", instance, instance.state["Name"])
-        instance = resources.ec2.Instance(instance.id)
-        time.sleep(1)
+    instance.wait_until_running()
     if args.use_dns:
         dns_zone.update(args.hostname, instance.private_dns_name)
+    if args.use_imdsv2:
+        clients.ec2.modify_instance_metadata_options(InstanceId=instance.id, HttpTokens="required")
     add_ssh_host_key_to_known_hosts(hostkey_line([instance.public_dns_name or instance.id], ssh_host_key))
     if args.wait_for_ssh:
         wait_for_port(instance.public_dns_name, 22)
-    logger.info("Launched %s in %s using %s", instance, subnet, args.ami)
+    logger.info("Launched %s in %s using %s (%s)", instance, subnet, args.ami, args.ami.name)
     return dict(instance_id=instance.id)
 
 parser = register_parser(launch)
 parser.add_argument("hostname")
-parser.add_argument("--storage", nargs="+", metavar="MOUNTPOINT=SIZE_GB",
-                    type=lambda x: x.rstrip("GBgb").split("=", 1),
+parser.add_argument("--storage", nargs="+", metavar="MOUNTPOINT=SIZE_GB", type=lambda x: x.split("=", 1),
                     help="At launch time, attach EBS volume(s) of this size, format and mount them.")
 parser.add_argument("--efs-home", action="store_true",
                     help="Create and manage an EFS filesystem that the instance will use for user home directories")
@@ -295,10 +312,16 @@ parser.add_argument("--tags", nargs="+", metavar="NAME=VALUE", type=lambda x: x.
 parser.add_argument("--wait-for-ssh", action="store_true",
                     help=("Wait for launched instance to begin accepting SSH connections. "
                           "Security groups and NACLs must permit SSH from launching host."))
-parser.add_argument("--iam-role", default=__name__,
-                    help=("Pass this IAM role to the launched instance through an instance profile. "
-                          "Role credentials will become available in the instance metadata."))
+parser.add_argument("--iam-role", help=("Pass this IAM role to the launched instance through an instance profile. "
+                                        "Role credentials will become available in the instance metadata. "
+                                        "To launch an instance without a profile/role, use an empty string here."))
 parser.add_argument("--iam-policies", nargs="+", metavar="IAM_POLICY_NAME",
                     help="Ensure the default or specified IAM role has the listed IAM managed policies attached")
+parser.add_argument("--use-imdsv2", "--metadata-options-http-tokens-required", action="store_true",
+                    help="Configure the instance to use Instance Metadata Service Version 2")
+parser.add_argument("--no-manage-iam", action="store_false", dest="manage_iam",
+                    help=("Prevents aegea from creating or managing the IAM role or policies for the instance. The "
+                          "given or default IAM role and instance profile will still be used, raising an error if they "
+                          "are not found."))
 parser.add_argument("--cloud-config-data", type=json.loads)
 parser.add_argument("--dry-run", "--dryrun", action="store_true")
