@@ -1,7 +1,6 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import os, sys, json, re
 from datetime import datetime, timedelta
+from statistics import median
 
 import boto3, requests
 
@@ -9,7 +8,6 @@ from . import register_parser
 from .util import paginate, Timestamp
 from .util.printing import format_table, page_output, tabulate, format_datetime
 from .util.aws import region_name, offers_api, clients, instance_type_completer, get_products
-from .util.compat import median
 
 def describe_services():
     client = boto3.client("pricing", region_name="us-east-1")
