@@ -1,23 +1,28 @@
 """
 Connect to an EC2 instance via SSH, by name or instance ID.
 
-Security groups, network ACLs, interfaces, VPC routing tables, VPC
-Internet Gateways, and internal firewalls for the instance must be
-configured to allow SSH connections.
+By default, aegea uses AWS SSM with EC2 Instance Connect to open an SSH
+connection to your instance. This means you don't have to create security group
+rules to allow inbound TCP port 22 access, nor distribute your SSH public keys
+to your instance in advance of logging in; however, you do still need to
+provision the Linux user on the instance before logging in as that user (unless
+using the default pre-provisioned ubuntu or ec2-user account).
 
-To facilitate SSH connections, ``aegea ssh`` resolves instance names
-to public DNS names assigned by AWS, and securely retrieves SSH host
-public keys from instance metadata before connecting. This avoids both
-the prompt to save the instance public key and the resulting transient
-MITM vulnerability.
+AWS SSM can be disabled using the --no-ssm option. EC2 Instance Connect can be
+disabled using the --no-ec2-instance-connect option.
 
-``aegea ssh`` also supports Bless, via the --bless-config CONFIG_FILE
-option or the BLESS_CONFIG environment variable. This should point to a
-YAML file with the format described in
-https://github.com/chanzuckerberg/blessclient/blob/master/examples/config.yml.
+To facilitate SSH connections, ``aegea ssh`` resolves instance names to public
+DNS names assigned by AWS, and securely retrieves SSH host public keys from
+instance metadata before connecting. This avoids both the prompt to save the
+instance public key and the resulting transient MITM vulnerability.
+
+Security groups, network ACLs, interfaces, VPC routing tables, VPC Internet
+Gateways, and internal firewalls for the instance must be configured to allow
+SSH connections.
 """
 
 import os, sys, argparse, string, datetime, json, base64, time, fnmatch, subprocess, hashlib
+from functools import lru_cache
 
 import boto3, yaml
 
@@ -27,7 +32,6 @@ from .util.crypto import (add_ssh_host_key_to_known_hosts, ensure_local_ssh_key,
                           add_ssh_key_to_agent, get_ssh_key_path, get_ssh_id)
 from .util.printing import BOLD
 from .util.exceptions import AegeaException
-from .util.compat import lru_cache
 from .util.aws.ssm import ensure_session_manager_plugin, run_command
 
 opts_by_nargs = {
@@ -76,12 +80,9 @@ def resolve_instance_public_dns(name):
     return instance.public_dns_name
 
 def get_user_info():
-    res = clients.sts.get_caller_identity()
-    iam_username = ARN(res["Arn"]).resource.split("/")[1]
+    iam_username = ARN.get_iam_username()
     linux_username, at, domain = iam_username.partition("@")
-    iam_user_id = res["UserId"]
-    iam_user_id, colon, session = iam_user_id.partition(":")
-    user_id_bytes = hashlib.sha256(iam_user_id.encode()).digest()[-2:]
+    user_id_bytes = hashlib.sha256(iam_username.encode()).digest()[-2:]
     linux_user_id = str(2000 + (int.from_bytes(user_id_bytes, byteorder=sys.byteorder) // 2))
     return dict(iam_username=iam_username, linux_username=linux_username, linux_user_id=linux_user_id)
 
@@ -172,6 +173,10 @@ def match_instance_to_bastion(instance, bastions):
 
 def prepare_ssh_host_opts(username, hostname, bless_config_filename=None, ssh_key_name=__name__, use_kms_auth=True,
                           use_ssm=True, use_ec2_instance_connect=True):
+    instance = get_instance(hostname)
+    if not getattr(get_instance(hostname), "subnet", None):
+        msg = "Unable to resolve subnet for {} (state: {})"
+        raise AegeaException(msg.format(instance, getattr(instance, "state", {}).get("Name")))
     if bless_config_filename:
         with open(bless_config_filename) as fh:
             bless_config = yaml.safe_load(fh)
@@ -179,7 +184,6 @@ def prepare_ssh_host_opts(username, hostname, bless_config_filename=None, ssh_ke
                               bless_config=bless_config,
                               use_kms_auth=use_kms_auth)
         add_ssh_key_to_agent(ssh_key_name)
-        instance = get_instance(hostname)
         bastion_config = match_instance_to_bastion(instance=instance, bastions=bless_config["ssh_config"]["bastions"])
         if not username:
             username = bastion_config["user"]
@@ -194,8 +198,8 @@ def prepare_ssh_host_opts(username, hostname, bless_config_filename=None, ssh_ke
         else:
             raise AegeaException("No bastion host or public route found for {}".format(instance))
     else:
-        if get_instance(hostname).key_name is not None:
-            add_ssh_key_to_agent(get_instance(hostname).key_name)
+        if instance.key_name is not None:
+            add_ssh_key_to_agent(instance.key_name)
         if not username:
             username = get_user_info()["linux_username"]
         save_instance_public_key(hostname, use_ssm=use_ssm)
@@ -203,12 +207,12 @@ def prepare_ssh_host_opts(username, hostname, bless_config_filename=None, ssh_ke
             ssh_public_key = get_ssh_id()
             logger.info("Sending SSH public key %s for %s to %s", ssh_public_key.split()[-1], username, hostname)
             clients.ec2_instance_connect.send_ssh_public_key(
-                InstanceId=get_instance(hostname).id,
+                InstanceId=instance.id,
                 InstanceOSUser=username,
                 SSHPublicKey=ssh_public_key,
-                AvailabilityZone=get_instance(hostname).subnet.availability_zone
+                AvailabilityZone=instance.placement["AvailabilityZone"]
             )
-        return [], username + "@" + (get_instance(hostname).id if use_ssm else resolve_instance_public_dns(hostname))
+        return [], username + "@" + (instance.id if use_ssm else resolve_instance_public_dns(hostname))
 
 def init_ssm(instance_id):
     ssm_plugin_path = ensure_session_manager_plugin()
