@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import os, sys, json, io, gzip, time, socket, hashlib, uuid
 import requests
 from warnings import warn
@@ -9,12 +7,11 @@ from typing import List, Dict, Any
 
 import boto3, botocore.session
 from botocore.exceptions import ClientError
-from botocore.utils import parse_to_aware_datetime
+from botocore.utils import parse_to_aware_datetime, InstanceMetadataFetcher as IMDS
 
 from ... import logger
 from .. import paginate
 from ..exceptions import AegeaException
-from ..compat import str
 from . import clients, resources
 
 def get_ssm_parameter(name):
@@ -32,7 +29,7 @@ def locate_ami(distribution, release, architecture):
         ssm_param_name = "/aws/service/ami-amazon-linux-latest/amzn2-ami-hvm-{}-gp2".format(architecture)
         ami_id = clients.ssm.get_parameters(Names=[ssm_param_name])["Parameters"][0]["Value"]
         logger.info("Found %s for %s %s %s", ami_id, distribution, release, architecture)
-        return ami_id
+        return resources.ec2.Image(ami_id)
     elif distribution == "Ubuntu":
         if architecture == "x86_64":
             architecture = "amd64"
@@ -40,7 +37,7 @@ def locate_ami(distribution, release, architecture):
         ssm_param_name = ssm_param_name.format(product="server", release=release, arch=architecture)
         ami_id = clients.ssm.get_parameters(Names=[ssm_param_name])["Parameters"][0]["Value"]
         logger.info("Found %s for %s %s %s", ami_id, distribution, release, architecture)
-        return ami_id
+        return resources.ec2.Image(ami_id)
     raise AegeaException("No AMI found for {} {} {}".format(distribution, release, architecture))
 
 def ensure_vpc():
@@ -59,6 +56,7 @@ def ensure_vpc():
             tags = dict(Name="aegea-vpc", managedBy="aegea")
             tag_spec = dict(ResourceType="vpc", Tags=encode_tags(tags))
             vpc = resources.ec2.create_vpc(CidrBlock=config.vpc.cidr[ARN.get_region()], TagSpecifications=[tag_spec])
+            time.sleep(1)
             clients.ec2.get_waiter("vpc_available").wait(VpcIds=[vpc.id])
             vpc.modify_attribute(EnableDnsSupport=dict(Value=config.vpc.enable_dns_support))
             vpc.modify_attribute(EnableDnsHostnames=dict(Value=config.vpc.enable_dns_hostnames))
@@ -191,7 +189,8 @@ class S3BucketLifecycleBuilder:
     def __iter__(self):
         yield ("Rules", self.rules)
 
-def ensure_s3_bucket(name=None, policy=None, lifecycle=None):
+def ensure_s3_bucket(name=None, policy=None, lifecycle=None, encryption=None):
+    from ... import config
     if name is None:
         name = "aegea-assets-{}".format(ARN.get_account_id())
     bucket = resources.s3.Bucket(name)
@@ -204,6 +203,16 @@ def ensure_s3_bucket(name=None, policy=None, lifecycle=None):
         else:
             bucket.create(CreateBucketConfiguration=dict(LocationConstraint=ARN.get_region()))
     bucket.wait_until_exists()
+    if encryption is None:
+        encryption = json.loads(config.s3.default_encryption_config)
+    try:
+        clients.s3.get_bucket_encryption(Bucket=bucket.name)
+    except ClientError as e:
+        expect_error_codes(e, "ServerSideEncryptionConfigurationNotFoundError", "AccessDenied")
+        try:
+            clients.s3.put_bucket_encryption(Bucket=bucket.name, ServerSideEncryptionConfiguration=encryption)
+        except ClientError as e:
+            expect_error_codes(e, "AccessDenied")
     if policy:
         bucket.Policy().put(Policy=str(policy))
     if lifecycle:
@@ -283,11 +292,11 @@ def resolve_instance_id(name):
     except IndexError:
         raise AegeaException('Could not resolve "{}" to a known instance'.format(name))
 
-def get_bdm(ami=None, max_devices=12, ebs_storage=frozenset()):
+def get_bdm(ami=None, max_devices=12, ebs_storage=None):
     # Note: d2.8xl and hs1.8xl have 24 devices
     bdm = [dict(VirtualName="ephemeral" + str(i), DeviceName="xvd" + chr(ord("b") + i)) for i in range(max_devices)]
     ebs_bdm = []  # type: List[Dict]
-    for i, (mountpoint, size_gb) in enumerate(ebs_storage):
+    for i, (mountpoint, size_gb) in enumerate(ebs_storage.items() if ebs_storage else []):
         if mountpoint == "/":
             rootfs_bdm = resources.ec2.Image(ami).block_device_mappings[0]
             if "Ebs" not in rootfs_bdm or "SnapshotId" not in rootfs_bdm.get("Ebs", []):
@@ -301,10 +310,10 @@ def get_bdm(ami=None, max_devices=12, ebs_storage=frozenset()):
     bdm.extend(ebs_bdm)
     return bdm
 
-def get_metadata(path):
-    res = requests.get("http://169.254.169.254/latest/meta-data/{}".format(path))
-    res.raise_for_status()
-    return res.content.decode()
+def get_metadata(category):
+    imds = IMDS()
+    token = imds._fetch_metadata_token()
+    return imds._get_request(url_path=f"latest/meta-data/{category}", retry_func=None, token=token).text
 
 def get_ecs_task_metadata(path="/task"):
     res = requests.get(os.environ["ECS_CONTAINER_METADATA_URI"] + path)
@@ -326,7 +335,9 @@ def resolve_ami(ami=None, arch="x86_64", tags=frozenset(), tag_keys=frozenset())
     """
     assert arch in {"x86_64", "arm64"}
 
-    if ami is None or not ami.startswith("ami-"):
+    if ami is not None and ami.startswith("ami-"):
+        return resources.ec2.Image(ami)
+    else:
         if ami is None:
             filters = dict(Owners=["self"],
                            Filters=[dict(Name="state", Values=["available"]), dict(Name="architecture", Values=[arch])])
@@ -347,8 +358,7 @@ def resolve_ami(ami=None, arch="x86_64", tags=frozenset(), tag_keys=frozenset())
                 amis = sorted(all_amis, key=lambda x: x.creation_date)
         if not amis:
             raise AegeaException("Could not resolve AMI {}".format(dict(tags, ami=ami)))
-        ami = amis[-1].id
-    return ami
+        return amis[-1]
 
 offers_api = "https://pricing.us-east-1.amazonaws.com/offers/v1.0"
 
