@@ -1,9 +1,7 @@
 #!/usr/bin/env python
-# coding: utf-8
-
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import os, sys, unittest, argparse, collections, copy, re, subprocess, importlib, pkgutil, json, datetime, glob, time
+from unittest.mock import patch
 
 pkg_root = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))  # noqa
 sys.path.insert(0, pkg_root)  # noqa
@@ -16,7 +14,6 @@ from aegea.util.aws import (resolve_ami, locate_ami, get_ondemand_price_usd, ARN
 from aegea.util.aws.iam import IAMPolicyBuilder
 from aegea.util.aws.batch import ensure_job_definition
 from aegea.util.aws.spot import SpotFleetBuilder
-from aegea.util.compat import USING_PYTHON2, str
 from aegea.util.exceptions import AegeaException
 from aegea.util.git import private_submodules
 
@@ -86,7 +83,7 @@ class TestAegea(unittest.TestCase):
             elif subcommand in ("start", "stop", "reboot", "terminate", "rename"):
                 args += [instance_id, instance_id, "--dry-run"]
             elif subcommand in ("grep", "filter"):
-                args += ["--help"] if USING_PYTHON2 else ["error", "syslog", "--start-time=-2h", "--end-time=-5m"]
+                args += ["error", "syslog", "--start-time=-2h", "--end-time=-5m"]
                 expect.append(dict(return_codes=[os.EX_DATAERR]))
             elif subcommand == "launch":
                 args += ["--no-verify-ssh-key-pem-file", "--dry-run", "test", "--ubuntu-linux-ami"]
@@ -215,8 +212,7 @@ class TestAegea(unittest.TestCase):
         self.assertEqual(len(policy.policy["Statement"]), 7)
 
     def test_aws_utils(self):
-        if not USING_PYTHON2:
-            self.assertTrue(isinstance(get_ondemand_price_usd("us-east-1", "t2.micro"), str))
+        self.assertTrue(isinstance(get_ondemand_price_usd("us-east-1", "t2.micro"), str))
         self.assertEquals(str(ARN(region="", account_id="")), "arn:aws::::")
         self.assertTrue(str(ARN()).startswith("arn:aws:"))
         self.assertEquals(str(ARN("arn:aws:foo:bar:xyz:zzt")), "arn:aws:foo:bar:xyz:zzt")
@@ -252,10 +248,10 @@ class TestAegea(unittest.TestCase):
         make_waiter(clients.efs.describe_file_systems, "FileSystems[].LifeCycleState", "available", "pathAny")
 
     def test_locate_ami(self):
-        self.assertTrue(locate_ami("Ubuntu", "20.04", "amd64").startswith("ami-"))
-        self.assertTrue(locate_ami("Ubuntu", "20.04", "arm64").startswith("ami-"))
-        self.assertTrue(locate_ami("Amazon Linux", "2", "x86_64").startswith("ami-"))
-        self.assertTrue(locate_ami("Amazon Linux", "2", "arm64").startswith("ami-"))
+        self.assertTrue(locate_ami("Ubuntu", "20.04", "amd64").id.startswith("ami-"))
+        self.assertTrue(locate_ami("Ubuntu", "20.04", "arm64").id.startswith("ami-"))
+        self.assertTrue(locate_ami("Amazon Linux", "2", "x86_64").id.startswith("ami-"))
+        self.assertTrue(locate_ami("Amazon Linux", "2", "arm64").id.startswith("ami-"))
 
     def test_ip_ranges(self):
         get_public_ip_ranges()
@@ -272,9 +268,8 @@ class TestAegea(unittest.TestCase):
             with self.assertRaises(Exception):
                 print(Timestamp(invalid_input))
 
-    @unittest.skipIf(USING_PYTHON2, "requires Python 3 dependencies")
     def test_deploy_utils(self):
-        deploy_utils_bindir = os.path.join(pkg_root, "aegea", "rootfs.skel", "usr", "bin")
+        deploy_utils_bindir = os.path.join(pkg_root, "aegea", "rootfs.skel.build_ami", "usr", "bin")
         for script in glob.glob(deploy_utils_bindir + "/aegea*"):
             self.call([script, "--help"], expect=[dict(return_codes=[0, 1])])
         for script in "aegea-deploy-pilot", "aegea-git-ssh-helper":
@@ -312,5 +307,25 @@ class TestAegea(unittest.TestCase):
         for submodule in private_submodules("git@github.com:ansible/ansible.git"):
             print(submodule)
 
+    def test_ssh_utils(self):
+        from aegea.util.aws.ssm import ensure_session_manager_plugin
+        ensure_session_manager_plugin()
+
+    def test_ssh_get_user_info(self):
+        from aegea.ssh import get_user_info
+        testcases = ((
+            "wookie",
+            {"iam_username": "wookie", "linux_user_id": "24073", "linux_username": "wookie"}
+        ), (
+            "unknown",
+            {"iam_username": "unknown", "linux_user_id": "26068", "linux_username": "unknown"}
+        ), (
+            "wookie.user@example.com",
+            {"iam_username": "wookie.user@example.com", "linux_user_id": "21919", "linux_username": "wookie.user"}
+        ))
+        for iam_username, expected_user_info in testcases:
+            with patch.object(ARN, "get_iam_username", lambda: iam_username):
+                self.assertDictEqual(get_user_info(), expected_user_info)
+
 if __name__ == '__main__':
     unittest.main()
